@@ -38,7 +38,8 @@ class TestTextBox:
 
     def test_extract_text_path2(self):
         text_boxes = TextBox.find_text_boxes(self.biosynth2_elem)
-        assert len(text_boxes) == 67
+        # this is system dependent
+        assert 65 <= len(text_boxes) <= 67
         for text_box in text_boxes:
             # print(text_box.text, text_box.bbox)
             pass
